@@ -1,3 +1,12 @@
+/* This is part of the netCDF package. Copyright 2005-2018 University
+   Corporation for Atmospheric Research/Unidata See COPYRIGHT file for
+   conditions of use.
+
+   Runs benchmarks on different chunking sizes.
+
+   Russ Rew, Ed Hartnett, Dennis Heimbigner
+*/
+
 #include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -9,14 +18,14 @@
 #include <sys/types.h>
 #endif
 #ifdef HAVE_SYS_TIMES_H
-#  include <sys/times.h>
+#include <sys/times.h>
 #endif
 #ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
 #endif
 #include <assert.h>
 #ifdef HAVE_SYS_RESOURCE_H
-#  include <sys/resource.h>
+#include <sys/resource.h>
 #endif
 #include "nc_tests.h"		/* The ERR macro is here... */
 #include "netcdf.h"
@@ -298,7 +307,7 @@ main(int argc, char *argv[]) {
     count[1] = dims[1];
     count[2] = dims[2];
 
-    sprintf(time_mess,"  contiguous write %3ld %3ld %3ld", 
+    sprintf(time_mess,"  contiguous write %3d %3ld %3ld",
 	    1, dims[1], dims[2]);
     TIMING_START ;
     for(i = 0; i < dims[0]; i++) {
@@ -310,7 +319,7 @@ main(int argc, char *argv[]) {
     printf("\n");
     contig_time = TMsec;
 
-    sprintf(time_mess,"  chunked    write %3ld %3ld %3ld  %3ld %3ld %3ld", 
+    sprintf(time_mess,"  chunked    write %3d %3ld %3ld  %3ld %3ld %3ld",
 	    1, dims[1], dims[2], chunks[0], chunks[1], chunks[2]);
     TIMING_START ;
     for(i = 0; i < dims[0]; i++) {
@@ -326,7 +335,7 @@ main(int argc, char *argv[]) {
     else
 	printf(" %5.2g x slower\n", 1.0/ratio);
 
-    sprintf(time_mess,"  compressed write %3ld %3ld %3ld  %3ld %3ld %3ld", 
+    sprintf(time_mess,"  compressed write %3d %3ld %3ld  %3ld %3ld %3ld",
 	    1, dims[1], dims[2], chunks[0], chunks[1], chunks[2]);
     TIMING_START ;
     for(i = 0; i < dims[0]; i++) {
@@ -351,7 +360,7 @@ main(int argc, char *argv[]) {
     count[1] = 1;
     count[2] = dims[2];
 
-    sprintf(time_mess,"  contiguous write %3ld %3ld %3ld", 
+    sprintf(time_mess,"  contiguous write %3ld %3d %3ld",
 	    dims[0], 1, dims[2]);
     TIMING_START ;
     for(i = 0; i < dims[1]; i++) {
@@ -363,7 +372,7 @@ main(int argc, char *argv[]) {
     printf("\n");
     contig_time = TMsec;
 
-    sprintf(time_mess,"  chunked    write %3ld %3ld %3ld  %3ld %3ld %3ld", 
+    sprintf(time_mess,"  chunked    write %3ld %3d %3ld  %3ld %3ld %3ld",
 	    dims[0], 1, dims[2], chunks[0], chunks[1], chunks[2]);
     TIMING_START ;
     for(i = 0; i < dims[1]; i++) {
@@ -379,7 +388,7 @@ main(int argc, char *argv[]) {
     else
 	printf(" %5.2g x slower\n", 1.0/ratio);
 
-    sprintf(time_mess,"  compressed write %3ld %3ld %3ld  %3ld %3ld %3ld", 
+    sprintf(time_mess,"  compressed write %3ld %3d %3ld  %3ld %3ld %3ld",
 	    dims[0], 1, dims[2], chunks[0], chunks[1], chunks[2]);
     TIMING_START ;
     for(i = 0; i < dims[1]; i++) {
@@ -404,7 +413,7 @@ main(int argc, char *argv[]) {
     count[1] = dims[1];
     count[2] = 1;
 
-    sprintf(time_mess,"  contiguous write %3ld %3ld %3ld", 
+    sprintf(time_mess,"  contiguous write %3ld %3ld %3d",
 	    dims[0], dims[1], 1);
     TIMING_START ;
     for(i = 0; i < dims[2]; i++) {
@@ -416,7 +425,7 @@ main(int argc, char *argv[]) {
     printf("\n");
     contig_time = TMsec;
     
-    sprintf(time_mess,"  chunked    write %3ld %3ld %3ld  %3ld %3ld %3ld", 
+    sprintf(time_mess,"  chunked    write %3ld %3ld %3d  %3ld %3ld %3ld",
 	    dims[0], dims[1], 1, chunks[0], chunks[1], chunks[2]);
     TIMING_START ;
     for(i = 0; i < dims[2]; i++) {
@@ -432,7 +441,7 @@ main(int argc, char *argv[]) {
     else
 	printf(" %5.2g x slower\n", 1.0/ratio);
 
-    sprintf(time_mess,"  compressed write %3ld %3ld %3ld  %3ld %3ld %3ld", 
+    sprintf(time_mess,"  compressed write %3ld %3ld %3d  %3ld %3ld %3ld",
 	    dims[0], dims[1], 1, chunks[0], chunks[1], chunks[2]);
     TIMING_START ;
     for(i = 0; i < dims[2]; i++) {
@@ -457,7 +466,7 @@ main(int argc, char *argv[]) {
     count[1] = dims[1];
     count[2] = dims[2];
 
-    sprintf(time_mess,"  contiguous  read %3ld %3ld %3ld", 
+    sprintf(time_mess,"  contiguous  read %3d %3ld %3ld",
 	    1, dims[1], dims[2]);
     TIMING_START ;
     for(i = 0; i < dims[0]; i++) {
@@ -469,7 +478,7 @@ main(int argc, char *argv[]) {
     printf("\n");
     contig_time = TMsec;
     
-    sprintf(time_mess,"  chunked     read %3ld %3ld %3ld  %3ld %3ld %3ld", 
+    sprintf(time_mess,"  chunked     read %3d %3ld %3ld  %3ld %3ld %3ld",
 	    1, dims[1], dims[2] , chunks[0], chunks[1], chunks[2]);
     TIMING_START ;
     for(i = 0; i < dims[0]; i++) {
@@ -485,7 +494,7 @@ main(int argc, char *argv[]) {
     else
 	printf(" %5.2g x slower\n", 1.0/ratio);
     
-    sprintf(time_mess,"  compressed  read %3ld %3ld %3ld  %3ld %3ld %3ld", 
+    sprintf(time_mess,"  compressed  read %3d %3ld %3ld  %3ld %3ld %3ld",
 	    1, dims[1], dims[2] , chunks[0], chunks[1], chunks[2]);
     TIMING_START ;
     for(i = 0; i < dims[0]; i++) {
@@ -510,7 +519,7 @@ main(int argc, char *argv[]) {
     count[1] = 1;
     count[2] = dims[2];
 
-    sprintf(time_mess,"  contiguous  read %3ld %3ld %3ld", 
+    sprintf(time_mess,"  contiguous  read %3ld %3d %3ld",
 	    dims[0], 1, dims[2]);
     TIMING_START ;
     for(i = 0; i < dims[1]; i++) {
@@ -522,7 +531,7 @@ main(int argc, char *argv[]) {
     printf("\n");
     contig_time = TMsec;
     
-    sprintf(time_mess,"  chunked     read %3ld %3ld %3ld  %3ld %3ld %3ld", 
+    sprintf(time_mess,"  chunked     read %3ld %3d %3ld  %3ld %3ld %3ld",
 	    dims[0], 1, dims[2], chunks[0], chunks[1], chunks[2]);
     TIMING_START ;
     for(i = 0; i < dims[1]; i++) {
@@ -538,7 +547,7 @@ main(int argc, char *argv[]) {
     else
 	printf(" %5.2g x slower\n", 1.0/ratio);
     
-    sprintf(time_mess,"  compressed  read %3ld %3ld %3ld  %3ld %3ld %3ld", 
+    sprintf(time_mess,"  compressed  read %3ld %3d %3ld  %3ld %3ld %3ld",
 	    dims[0], 1, dims[2], chunks[0], chunks[1], chunks[2]);
     TIMING_START ;
     for(i = 0; i < dims[1]; i++) {
@@ -563,7 +572,7 @@ main(int argc, char *argv[]) {
     count[1] = dims[1];
     count[2] = 1;
 
-    sprintf(time_mess,"  contiguous  read %3ld %3ld %3ld", 
+    sprintf(time_mess,"  contiguous  read %3ld %3ld %3d",
 	    dims[0], dims[1], 1);
     TIMING_START ;
     for(i = 0; i < dims[2]; i++) {
@@ -575,7 +584,7 @@ main(int argc, char *argv[]) {
     printf("\n");
     contig_time = TMsec;
 
-    sprintf(time_mess,"  chunked     read %3ld %3ld %3ld  %3ld %3ld %3ld", 
+    sprintf(time_mess,"  chunked     read %3ld %3ld %3d  %3ld %3ld %3ld",
 	    dims[0], dims[1], 1, chunks[0], chunks[1], chunks[2]);
     TIMING_START ;
     for(i = 0; i < dims[2]; i++) {
@@ -591,7 +600,7 @@ main(int argc, char *argv[]) {
     else
 	printf(" %5.2g x slower\n", 1.0/ratio);
 
-    sprintf(time_mess,"  compressed  read %3ld %3ld %3ld  %3ld %3ld %3ld", 
+    sprintf(time_mess,"  compressed  read %3ld %3ld %3d  %3ld %3ld %3ld",
 	    dims[0], dims[1], 1, chunks[0], chunks[1], chunks[2]);
     TIMING_START ;
     for(i = 0; i < dims[2]; i++) {
